@@ -12,7 +12,7 @@ use Encode qw(decode);
 
 use vars qw[ $VERSION ];
 
-$VERSION = '0.28';
+$VERSION = '0.29';
 
 BEGIN {
   Finance::Bank::Postbank_de->mk_accessors(qw( agent login password urls ));
@@ -97,7 +97,7 @@ sub get_login_page {
   $self->agent(WWW::Mechanize->new( autocheck => 1, keep_alive => 1 ));
 
   my $agent = $self->agent();
-  $agent->add_header("If-SSL-Cert-Subject" => qr'/1\.3\.6\.1\.4\.1\.311\.60\.2\.1\.3=DE/1\.3\.6\.1\.4\.1\.311\.60\.2\.1\.1=Bonn/2\.5\.4\.15=Private Organization/serialNumber=HRB6793/C=DE/postalCode=53113/ST=NRW/L=Bonn/streetAddress=Friedrich Ebert Allee 114 126/O=Deutsche Postbank AG/OU=Systems AG/CN=banking\.postbank\.de'); 
+  $agent->add_header("If-SSL-Cert-Subject" => qr{\Q/1.3.6.1.4.1.311.60.2.1.3=DE/1.3.6.1.4.1.311.60.2.1.1=Bonn/businessCategory=Private Organization/serialNumber=HRB6793/C=DE/postalCode=53113/ST=NRW/L=Bonn/street=Friedrich Ebert Allee 114 126/O=Deutsche Postbank AG/OU=Systems AG/CN=banking.postbank.de}); 
 
   $agent->get(LOGIN);
   $self->log_httpresult();
@@ -157,7 +157,7 @@ sub access_denied {
          $message =~ m!^Die Kontonummer ist nicht fr das Internet Online-Banking freigeschaltet. Bitte verwenden Sie zur Freischaltung den Link "Online-Banking freischalten"\.<br />\s*$!sm
       or $message =~ m!^Sie haben zu viele Zeichen in das Feld eingegeben.<br />\s*$!sm
       or $message =~ m!^Die eingegebene Postbank Girokontonummer ist zu lang. Bitte berprfen Sie Ihre Eingabe.$!sm
-      or $message =~ m!^Die Anmeldung ist fehlgeschlagen. Bitte vergewissern Sie sich ber die Richtigkeit Ihrer Eingaben und fhren Sie den Anmeldevorgang erneut durch.\s*$!sm
+      or $message =~ m!^Die Anmeldung ist fehlgeschlagen. Bitte vergewissern Sie sich der Richtigkeit Ihrer Eingaben und f.hren Sie den Anmeldevorgang erneut durch.\s*$!sm
     )
   } else {
     return;
@@ -354,6 +354,8 @@ sub get_account_statement {
 1;
 __END__
 
+=encoding ISO8859-1
+
 =head1 NAME
 
 Finance::Bank::Postbank_de - Check your Postbank.de bank account from Perl
